@@ -3,7 +3,8 @@
 #'
 #' Gets an XML representation out of the polyhedron object
 #'
-#' @param polyhedron.state.defined the polyhedron to get a representation from
+#' @param polyhedron.state.defined the polyhedron to get a
+#'        representation from
 #' @return a XML document, ready to be saved as a String File
 # TODO examples
 #' @examples
@@ -11,10 +12,9 @@
 #' library(Rpolyhedra)
 #' polyhedronToXML(getPolyhedron("netlib", "cube")$getState())
 #'
-#' @import XML
+#' @importFrom XML xmlTree
 #' @export
-polyhedronToXML <- function(polyhedron.state.defined)
-{
+polyhedronToXML <- function(polyhedron.state.defined) {
   xml <- XML::xmlTree()
   #xml$addTag("polyhedron", close=FALSE)
   #xml$closeTag()
@@ -30,10 +30,10 @@ polyhedronToXML <- function(polyhedron.state.defined)
 #' @param file.path the path of the file to be persisted.
 #' @return the path or None
 #'
-persistPolyhedron <- function(polyhedron.state.defined, file.path)
-{
+persistPolyhedron <- function(polyhedron.state.defined, file.path) {
   polyhedron.xml <- polyhedronToXML(polyhedron.state.defined)
-  temp.file <- file(tempfile(pattern = "polyhedron", tmpdir = tempdir(), fileext = ""))
+  temp.file <- file(tempfile(pattern = "polyhedron",
+                             tmpdir = tempdir(), fileext = ""))
   write(polyhedron.xml)
 
   zip(file.path, temp.file)
@@ -47,9 +47,6 @@ persistPolyhedron <- function(polyhedron.state.defined, file.path)
 #' @param file.path the path of the file to be hydrated.
 #' @return polyhedron.state.defined
 #'
-hydratePolyhedron <- function(file.path)
-{
+hydratePolyhedron <- function(file.path) {
 
 }
-
-
